OC.L10N.register(
    "serverinfo",
    {
    "Not supported!" : "Tidak menyokong!",
    "Press ⌘-C to copy." : "Tekan ⌘-C untuk menyalin.",
    "Press Ctrl-C to copy." : "Tekan Ctrl-C untuk menyalin.",
    "Size:" : "Saiz",
    "Shares" : "Kongsi",
    "Type:" : "Jenis",
    "Users" : "Pengguna",
    "Groups" : "Kumpulan",
    "Copied!" : "Disalin!",
    "Size" : "Saiz",
    "Files" : "Fail",
    "Type" : "Jenis"
},
"nplurals=1; plural=0;");
